@@ -54,17 +54,6 @@
 
 #define SNAP_LEN 1514
 
-#define FLAG_IPCHG      0x00000001 // 0
-#define FLAG_ALLOW      0x00000002 // 1
-#define FLAG_DENY       0x00000004 // 2
-#define FLAG_NEW        0x00000008 // 3
-#define FLAG_UNAUTH_RQ  0x00000010 // 4
-#define FLAG_ABUS       0x00000020 // 5
-#define FLAG_BOGON      0x00000040 // 6
-#define FLAG_FLOOD      0x00000080 // 7
-#define FLAG_NEWMAC     0x00000100 // 8
-#define FLAG_MACCHG     0x00000200 // 9
-
 extern int errno;
 
 // constantes
@@ -105,6 +94,7 @@ int flag_to_no(U_INT32_T flag){
 		case FLAG_FLOOD:     return AL_FLOOD;           break;
 		case FLAG_NEWMAC:    return AL_NEW_MAC;         break;
 		case FLAG_MACCHG:    return AL_MAC_CHANGE;      break;
+		case FLAG_MACEXPIRE: return AL_MAC_EXPIRE;      break;
 	}
 	return -1;
 }
@@ -323,6 +313,10 @@ void cap_init(void){
 	if(IS_CONF(CF_ALERT_DENY))      alert_bitfield |= FLAG_DENY;
 	if(IS_CONF(CF_MOD_DENY))        mod_bitfield   |= FLAG_DENY;
 
+	if(IS_CONF(CF_LOG_EXPIRE))      log_bitfield   |= FLAG_MACEXPIRE;
+	if(IS_CONF(CF_ALERT_EXPIRE))    alert_bitfield |= FLAG_MACEXPIRE;
+	if(IS_CONF(CF_MOD_EXPIRE))      mod_bitfield   |= FLAG_MACEXPIRE;
+
 	// if no device specified, auto select the first
 	if(config[CF_IF].valeur.string == NULL ||
 	   config[CF_IF].valeur.string[0] == 0){
