@@ -21,6 +21,7 @@
 #include "data.h"
 #include "log.h"
 #include "loadconfig.h"
+#include "capture.h"
 #include "func_time.h"
 #include "func_str.h"
 
@@ -172,6 +173,27 @@ void data_reset(void){
 	}
 }
 
+// clear all status
+void data_reset_status(void){
+	struct data_pack *cls;
+	struct data_pack *clsnext;
+	struct data_pack *base;
+	int step;
+
+	step = 0;
+	while(step < HASH_SIZE){
+		base = &data_mac_tab[step];
+		base->flag = APPEND;
+		clsnext = base->next_mac;
+		while(clsnext != base){
+			cls = clsnext;
+			clsnext = clsnext->next_mac;
+			cls->flag = APPEND;
+		}
+		step++;
+	}
+}
+
 // update mac address in hash
 void data_update_field(struct ether_addr *mac, int status,
                     struct in_addr ip,
@@ -484,7 +506,28 @@ void data_clean(void){
 			// get next
 			clean_next = clean->next_chain;
 	
-			if(clean->flag == APPEND){
+			if(
+			   clean->flag == APPEND ||
+			   (
+			      clean->flag == ALLOW &&
+			      config[CF_EXPIRE_AUTH].valeur.integer == TRUE &&
+			      ISSET_MAC_EXPIRE(clean->alerts) == FALSE
+			   )
+			){
+				if(
+					// check if mac expire alert is configured
+					config[CF_ALERT_EXPIRE].valeur.integer == TRUE ||
+					config[CF_LOG_EXPIRE].valeur.integer == TRUE ||
+					config[CF_MOD_EXPIRE].valeur.integer == TRUE
+				){
+					#ifdef DEBUG_DETECT
+					logmsg(LOG_DEBUG, "[%s %d]  -> EXPIRED", __FILE__, __LINE__);
+					#endif
+
+					send_alert(&clean->mac, clean->ip, FLAG_MACEXPIRE,
+					           &null_mac, null_ip, clean->cap_id->device);
+				}
+
 				// unindex ip hash
 				clean->prev_ip->next_ip = clean->next_ip;
 				clean->next_ip->prev_ip = clean->prev_ip;
