@@ -58,6 +58,9 @@ enum {
 	// module config string
 	CF_MOD_CONFIG,
 
+	// expire for allowed hosts
+	CF_EXPIRE_AUTH,
+
 	// config alerts for logs
 	CF_LOG_FLOOD,
 	CF_LOG_NEWMAC,
@@ -69,6 +72,7 @@ enum {
 	CF_LOG_ABUS,
 	CF_LOG_ALLOW,
 	CF_LOG_DENY,
+	CF_LOG_EXPIRE,
 
 	// config alerts for script
 	CF_ALERT_FLOOD,
@@ -81,6 +85,7 @@ enum {
 	CF_ALERT_ABUS,
 	CF_ALERT_ALLOW,
 	CF_ALERT_DENY,
+	CF_ALERT_EXPIRE,
 	
 	// config alerts for module
 	CF_MOD_FLOOD,
@@ -93,6 +98,7 @@ enum {
 	CF_MOD_ABUS,
 	CF_MOD_ALLOW,
 	CF_MOD_DENY,
+	CF_MOD_EXPIRE,
 
 	// total number of arguments
 	NUM_PARAMS
@@ -115,16 +121,17 @@ int flagdump;
  * value:
  *  valeur du parametre de type indefini
  */
-typedef struct {
+struct config_cell {
 	int		type;
 	char		*attrib;
 	union {
 		char	*string;
 		int	integer;
 	} valeur;
-} config_cell;
+};
+
+extern struct config_cell config[];
 
-config_cell config[NUM_PARAMS];
 char config_file[CONFIGFILE_LEN];
 
 // load config file values
