@@ -192,6 +192,9 @@ int maclist_file(char *file_name, int level, int mode){
 				else if(strcmp(args[i], "mac_change") == 0){
 					SET_MAC_CHANGE(bitfield);
 				}
+				else if(strcmp(args[i], "mac_expire") == 0){
+					SET_MAC_EXPIRE(bitfield);
+				}
 				else {
 					logmsg(LOG_ERR,
 					       "file: \"%s\", line %d: flag \"%s\" not availaible",
@@ -305,6 +308,9 @@ void maclist_reload(void){
 		}
 	}
 
+	// clear old status
+	data_reset_status();
+
 	// test black list
 	if(config[CF_BLACKLST].valeur.string != NULL &&
 	   config[CF_BLACKLST].valeur.string[0] != 0){
